pyhsm.basic_cmd.YHSM_Cmd_System_Info

Package pyhsm :: Module basic_cmd :: Class YHSM_Cmd_System_Info |
[frames] | no frames]

# Class YHSM_Cmd_System_Info

    cmd.YHSM_Cmd --+
                   |
                  YHSM_Cmd_System_Info

Request system information from the YubiHSM.

Instance Methods
__init__(self, stick) The base class for all YSM_ commands. |
__repr__(self) |
parse_result(self, data) This function is intended to be overridden by sub-classes that implements commands that should not just return the data read from the YubiHSM. |
Inherited from `cmd.YHSM_Cmd`: `execute`

Class Variables
Inherited from `cmd.YHSM_Cmd`: `executed`, `response_status`

Instance Variables
| version_major = `0` Major firmware version
| version_minor = `0` Minor firmware version
| version_build = `0` Firmware build version
| protocol_ver = `0` Communication protocol version
string | system_uid = `None` Unique identifier for YubiHSM

Method Details

### __init__(self, stick) (Constructor) |
The base class for all YSM_ commands. Parameters: `stick` - Reference to a YubiHSM `command` - The YSM_xxx command defined in pyhsm.defines. `payload` - a packed C struct, represented as a Python string Overrides: cmd.YHSM_Cmd.__init__ (inherited documentation)

### parse_result(self, data) |
This function is intended to be overridden by sub-classes that implements commands that should not just return the data read from the YubiHSM. Overrides: cmd.YHSM_Cmd.parse_result (inherited documentation)